summaryrefslogtreecommitdiffstats
path: root/kplato/kptresourceview.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kplato/kptresourceview.cc')
-rw-r--r--kplato/kptresourceview.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/kplato/kptresourceview.cc b/kplato/kptresourceview.cc
index d596ff44..58ea413e 100644
--- a/kplato/kptresourceview.cc
+++ b/kplato/kptresourceview.cc
@@ -203,7 +203,7 @@ protected:
c = fc;
// draw to last interesting column
- const TQColorGroup &cg = ( tqpalette().inactive() );
+ const TQColorGroup &cg = ( palette().inactive() );
while ( c < lc && !drawables.isEmpty() ) {
int i = header()->mapToLogical( c );
@@ -240,7 +240,7 @@ protected:
if ( tx < 0 )
tx = header()->cellPos( cell );
- // do any tqchildren of current need to be painted?
+ // do any children of current need to be painted?
/* FIXME: painting branches doesn't work for some reason...
if ( ih != ith &&
rootIsDecorated() &&
@@ -268,7 +268,7 @@ protected:
p->translate( rleft, crtop );
//kdDebug()<<k_funcinfo<<"paintBranches: "<<current->i->text(0)<<endl;
- current->i->paintBranches( p, tqcolorGroup(), treeStepSize(),
+ current->i->paintBranches( p, colorGroup(), treeStepSize(),
rtop - crtop, r.height() );
p->restore();
}
@@ -362,8 +362,8 @@ public:
TQDate date;
};
-TQSize ResourceView::tqsizeHint() const {
- return tqminimumSizeHint(); // HACK: koshell splitter tqminimumSize problem
+TQSize ResourceView::sizeHint() const {
+ return minimumSizeHint(); // HACK: koshell splitter minimumSize problem
}
ResourceView::ResourceView(View *view, TQWidget *parent)